import java.io.*;
import javax.net.ssl.*;
import java.net.URL;
import org.cmis.interopserver.services.tie.*;
import org.apache.axis.client.Call;
import org.apache.axis.client.Stub;
import org.apache.axis.AxisEngine;

public class SimplePingExample {
   public static void main(String[] args) {
      try {
        // Trust our site by dynamically adding its certificate to our store.
        TrustStoreManager s =
            new TrustStoreManager(System.getProperty("javax.net.ssl.trustStore"),
                                  "pw",
                                  "");
        s.trustSite("interop.cmiservices.org", 443);

         // Set up a connection to the TIE service. These locator classes are
         // generated by Axis, as described in the Web Services Development Guide,
         // or are defined in the client JAR that can be downloaded from this site.
         TieService service = new TieServiceLocator();

         URL svcURL = new URL("https://interop.cmiservices.org/axis/services/Tie");
         System.out.println("Invoking service at " + svcURL.toString());
         TieSoapBindingStub tie = (TieSoapBindingStub) service.getTie(svcURL);

         // Establish our credentials. Your COG/username is supplied when your
         // organization is registered with DMIS. These are the same credentials
         // used when logging into the DMIS tool suite.
         tie.setUsername("1737/yourlogin");
         tie.setPassword("yourpassword");

         // Invoke the TIE service! This line of code causes Axis to generate
         // a SOAP using the compiled stubs. Those stubs are ultimately traced
         // back to the WSDL for the TIE service. The "ping" method is one of
         // the methods defined in the WSDL.
         String pingResult = tie.ping();

         // Check the result against what we expect. The "ping" method returns
         // a single string value, "pong", so if we receive that value then we
         // we know the service is running and is accessible. A more useful
         // application could call other TIE functions at this point.
         if (pingResult == null)
            System.out.println("Did not receive result as expected");
         else if (pingResult.length() == 0)
            System.out.println("Did not receive result as expected");
         else if (pingResult.equalsIgnoreCase("pong"))
            System.out.println("Received the expected result: pong");
         else
            System.out.println("Receive a result but it was unexpected");
         }
      catch (Exception ex) {
         ex.printStackTrace();
      }
   }
}


